@@ -4,9 +4,7 @@ from notejob.center.app.core import db, scheduler
 from notejob.center.app.crons import cron_do
 from notejob.center.app.decorated import api_deal_return, api_err_return
 from notejob.center.configs import configs
-from notejob.center.datas.model.cron_infos import CronInfos
-from notejob.center.datas.model.job_log import JobLog
-from notejob.center.datas.model.job_log_items import JobLogItems
+from notejob.center.datas.model import CronInfos, JobLog, JobLogItems
 
 from .core import api
 
