@@ -6,9 +6,7 @@ from notejob.center.app.common.functions import web_api_return, wechat_info_err
 from notejob.center.app.core import db, scheduler
 from notejob.center.app.crons import cron_do
 from notejob.center.app.decorated import login_required
-from notejob.center.datas.model.cron_infos import CronInfos
-from notejob.center.datas.model.job_log import JobLog
-from notejob.center.datas.model.job_log_items import JobLogItems
+from notejob.center.datas.model import CronInfos, JobLog, JobLogItems
 from notejob.center.datas.utils.times import get_now_time
 
 from.core import blue_print
